@@ -1,20 +1,27 @@
-from typing import List, Tuple, Union, Dict, Any
+from __future__ import annotations
+from typing import List, Tuple, Union, Dict, Any, Callable
 
 from quaterion.dataset import SimilarityPairSample, SimilarityGroupSample
 from quaterion_models.types import CollateFnType
 
 
 class TrainCollater:
-    """
-    Functional object, that aggregates all required information for performing collate on train batches.
-    Should be serializable for sending among worker processes.
+    """Functional object, that aggregates all required information for performing collate on train
+    batches.
+
+    Note:
+        Should be serializable for sending among worker processes.
 
     Args:
-        pre_collate_fn:
-        encoder_collates:
+        pre_collate_fn: function to split origin batch into ids, features and labels. Ids are means
+            to keep track of repeatable usage of the same elements. Features are  commonly encoders
+            input. Labels usually allow distinguishing positive and negative samples.
+        encoder_collates: mapping of encoder name to its collate function
     """
 
-    def __init__(self, pre_collate_fn, encoder_collates: Dict[str, "CollateFnType"]):
+    def __init__(
+        self, pre_collate_fn: Callable, encoder_collates: Dict[str, CollateFnType]
+    ):
         self.pre_collate_fn = pre_collate_fn
         self.encoder_collates = encoder_collates
 
